an efficient function to find the neighborhood based on the matrix of position and a pre-defined cutoff
Usage
getneighborhood_fast(x, cutoff)
Arguments
x
is a n-by-2 matrix of position.
cutoff
is a threashold of Euclidean distance to decide whether a spot is an neighborhood of another spot. For example, if the Euclidean distance between spot A and B is less than cutoff, then A is taken as the neighbourhood of B.